@@ -31,6 +31,9 @@ import org.apache.spark.sql.datafu.types.SparkOverwriteUDAFs
 import org.apache.spark.sql.expressions.Window
 import org.apache.spark.sql.internal.StaticSQLConf.CATALOG_IMPLEMENTATION
 import org.apache.spark.sql.types._
+import java.io.File
+import java.nio.file.{Path, Paths, Files, SimpleFileVisitor, FileVisitResult}
+import java.nio.file.attribute.BasicFileAttributes
 
 @RunWith(classOf[JUnitRunner])
 class UdafTests extends FunSuite with DataFrameSuiteBase {
@@ -65,6 +68,25 @@ class UdafTests extends FunSuite with DataFrameSuiteBase {
   case class mapExp(map_col: Map[String, Int])
   case class mapArrExp(map_col: Map[String, Array[String]])
 
+  lazy val defaultDbLocation = spark.sql("describe database default").toDF
+	.collect()
+	.filter(_.getString(0) == "Location")(0)(1)
+	.toString.replace("file:", "")
+
+  def deleteLeftoverFiles(table : String) : Unit = {
+   
+	val tablePath = Paths.get(defaultDbLocation + File.separator + table)
+	
+	// sanity check - only delete files if the path seems to be to a Hive warehouse
+	if (defaultDbLocation.endsWith("warehouse") && Files.exists(tablePath)) Files.walkFileTree(tablePath, new SimpleFileVisitor[Path] {
+      		override def visitFile(path: Path, attrs: BasicFileAttributes): FileVisitResult = {
+        		Files.delete(path)
+        		FileVisitResult.CONTINUE
+      		}
+    	}
+  )
+ }
+
   test("test multiset simple") {
     val ms = new SparkUDAFs.MultiSet()
     val expected: DataFrame =
@@ -87,18 +109,20 @@ class UdafTests extends FunSuite with DataFrameSuiteBase {
   test("test multiarrayset all nulls") {
     // end case
     spark.sql("drop table if exists mas_table")
+    deleteLeftoverFiles("mas_table")
+    	
     spark.sql("create table mas_table (arr array<string>)")
     spark.sql(
       "insert overwrite table mas_table select case when 1=2 then array('asd') end " +
-        "from (select 1)z")
+        "from (select 1)")
     spark.sql(
-      "insert into table mas_table select case when 1=2 then array('asd') end from (select 1)z")
+      "insert into table mas_table select case when 1=2 then array('asd') end from (select 1)")
     spark.sql(
-      "insert into table mas_table select case when 1=2 then array('asd') end from (select 1)z")
+      "insert into table mas_table select case when 1=2 then array('asd') end from (select 1)")
     spark.sql(
-      "insert into table mas_table select case when 1=2 then array('asd') end from (select 1)z")
+      "insert into table mas_table select case when 1=2 then array('asd') end from (select 1)")
     spark.sql(
-      "insert into table mas_table select case when 1=2 then array('asd') end from (select 1)z")
+      "insert into table mas_table select case when 1=2 then array('asd') end from (select 1)")
 
     val expected = sqlContext.createDataFrame(List(mapExp(Map())))
 
@@ -111,19 +135,21 @@ class UdafTests extends FunSuite with DataFrameSuiteBase {
   test("test multiarrayset max keys") {
     // max keys case
     spark.sql("drop table if exists mas_table2")
+    deleteLeftoverFiles("mas_table2")
+
     spark.sql("create table mas_table2 (arr array<string>)")
     spark.sql(
-      "insert overwrite table mas_table2 select array('asd','dsa') from (select 1)z")
+      "insert overwrite table mas_table2 select array('asd','dsa') from (select 1)")
     spark.sql(
-      "insert into table mas_table2 select array('asd','abc') from (select 1)z")
+      "insert into table mas_table2 select array('asd','abc') from (select 1)")
     spark.sql(
-      "insert into table mas_table2 select array('asd') from (select 1)z")
+      "insert into table mas_table2 select array('asd') from (select 1)")
     spark.sql(
-      "insert into table mas_table2 select array('asd') from (select 1)z")
+      "insert into table mas_table2 select array('asd') from (select 1)")
     spark.sql(
-      "insert into table mas_table2 select array('asd') from (select 1)z")
+      "insert into table mas_table2 select array('asd') from (select 1)")
     spark.sql(
-      "insert into table mas_table2 select array('asd2') from (select 1)z")
+      "insert into table mas_table2 select array('asd2') from (select 1)")
 
     val mas2 = new SparkUDAFs.MultiArraySet[String](maxKeys = 2)
 
@@ -162,6 +188,8 @@ class UdafTests extends FunSuite with DataFrameSuiteBase {
     val mapMerge = new SparkUDAFs.MapSetMerge()
 
     spark.sql("drop table if exists mapmerge_table")
+    deleteLeftoverFiles("mapmerge_table")
+
     spark.sql("create table mapmerge_table (c map<string, array<string>>)")
     spark.sql(
       "insert overwrite table mapmerge_table select map('k1', array('v1')) from (select 1) z")
@@ -214,15 +242,18 @@ class UdafTests extends FunSuite with DataFrameSuiteBase {
   }
 
   case class Exp5(col_grp: String, col_ord: Option[Int])
+  case class Exp6(col_ord: Option[Int], col_grp: Option[Int])
 
   test("countDistinctUpTo") {
     import datafu.spark.SparkUDAFs.CountDistinctUpTo
 
+    val countDistinctUpTo2 = new CountDistinctUpTo(2)
     val countDistinctUpTo3 = new CountDistinctUpTo(3)
     val countDistinctUpTo6 = new CountDistinctUpTo(6)
-
+    
     val inputDF = sqlContext.createDataFrame(
       List(
+        Exp5("c", Option(1)),
         Exp5("b", Option(1)),
         Exp5("a", Option(1)),
         Exp5("a", Option(2)),
@@ -232,21 +263,26 @@ class UdafTests extends FunSuite with DataFrameSuiteBase {
 
     val results3DF = sqlContext.createDataFrame(
       List(
+        Exp5("c", Option(1)),
         Exp5("b", Option(1)),
         Exp5("a", Option(3))
       ))
 
     val results6DF = sqlContext.createDataFrame(
       List(
+        Exp5("c", Option(1)),
         Exp5("b", Option(1)),
         Exp5("a", Option(4))
       ))
 
-    inputDF
-      .groupBy("col_grp")
-      .agg(countDistinctUpTo3($"col_ord").as("col_ord"))
-      .show
-
+ val results2DF = sqlContext.createDataFrame(
+      List(
+      	Exp6(Option(1), Option(2)),
+      	Exp6(Option(3), Option(1)),
+        Exp6(Option(4), Option(1)),
+        Exp6(Option(2), Option(1))
+      ))
+      
     assertDataFrameEquals(results3DF,
                           inputDF
                             .groupBy("col_grp")
@@ -256,6 +292,10 @@ class UdafTests extends FunSuite with DataFrameSuiteBase {
                           inputDF
                             .groupBy("col_grp")
                             .agg(countDistinctUpTo6($"col_ord").as("col_ord")))
+                            
+       assertDataFrameEquals(results2DF,inputDF
+                            .groupBy("col_ord")
+                            .agg(countDistinctUpTo2($"col_grp").as("col_grp")))
   }
 
   test("test_limited_collect_list") {
